@@ -12,9 +12,11 @@ class StableDiffusionInpaintGenerator:
     def load_model(self, model_path):
         if self.pipe is None:
             self.pipe = DiffusionPipeline.from_pretrained(
-                model_path, safety_checker=None, torch_dtype=torch.float16
-            ).to("cuda")
-            self.pipe.enable_xformers_memory_efficient_attention()
+                model_path, revision="fp16", torch_dtype=torch.float16
+            )
+
+        self.pipe.to("cuda")
+        self.pipe.enable_xformers_memory_efficient_attention()
 
         return self.pipe
 
@@ -27,10 +29,18 @@ class StableDiffusionInpaintGenerator:
         num_images_per_prompt: int,
         guidance_scale: int,
         num_inference_step: int,
+        seed_generator=0,
     ):
         image = dict["image"].convert("RGB").resize((512, 512))
         mask_image = dict["mask"].convert("RGB").resize((512, 512))
         pipe = self.load_model(model_path)
+
+        if seed_generator == 0:
+            random_seed = torch.randint(0, 1000000, (1,))
+            generator = torch.manual_seed(random_seed)
+        else:
+            generator = torch.manual_seed(seed_generator)
+
         output = pipe(
             prompt=prompt,
             image=image,
@@ -39,6 +49,7 @@ class StableDiffusionInpaintGenerator:
             num_images_per_prompt=num_images_per_prompt,
             num_inference_steps=num_inference_step,
             guidance_scale=guidance_scale,
+            generator=generator,
         ).images
 
         return output
@@ -53,48 +64,62 @@ class StableDiffusionInpaintGenerator:
                         elem_id="image_upload",
                         type="pil",
                         label="Upload",
-                    )
-
-                    stable_diffusion_inpaint_model_id = gr.Dropdown(
-                        choices=stable_inpiant_model_list,
-                        value=stable_inpiant_model_list[0],
-                        label="Inpaint Model Id",
-                    )
+                    ).style(height=260)
 
                     stable_diffusion_inpaint_prompt = gr.Textbox(
-                        lines=1, value="Prompt", label="Prompt"
+                        lines=1, placeholder="Prompt", label="Prompt"
                     )
 
                     stable_diffusion_inpaint_negative_prompt = gr.Textbox(
                         lines=1,
-                        value="Negative Prompt",
+                        placeholder="Negative Prompt",
                         label="Negative Prompt",
                     )
+                    with gr.Row():
+                        with gr.Column():
+                            stable_diffusion_inpaint_model_id = gr.Dropdown(
+                                choices=stable_inpiant_model_list,
+                                value=stable_inpiant_model_list[0],
+                                label="Inpaint Model Id",
+                            )
+                            stable_diffusion_inpiant_num_images_per_prompt = (
+                                gr.Slider(
+                                    minimum=1,
+                                    maximum=10,
+                                    step=1,
+                                    value=1,
+                                    label="Number Of Images",
+                                )
+                            )
 
-                    stable_diffusion_inpiant_num_images_per_prompt = gr.Slider(
-                        minimum=1,
-                        maximum=10,
-                        step=1,
-                        value=1,
-                        label="Number Of Images",
-                    )
+                            stable_diffusion_inpaint_guidance_scale = gr.Slider(
+                                minimum=0.1,
+                                maximum=15,
+                                step=0.1,
+                                value=7.5,
+                                label="Guidance Scale",
+                            )
+                        with gr.Row():
+                            with gr.Column():
+                                stable_diffusion_inpaint_num_inference_step = (
+                                    gr.Slider(
+                                        minimum=1,
+                                        maximum=100,
+                                        step=1,
+                                        value=50,
+                                        label="Num Inference Step",
+                                    )
+                                )
 
-                    with gr.Accordion("Advanced Options", open=False):
-                        stable_diffusion_inpaint_guidance_scale = gr.Slider(
-                            minimum=0.1,
-                            maximum=15,
-                            step=0.1,
-                            value=7.5,
-                            label="Guidance Scale",
-                        )
-
-                        stable_diffusion_inpaint_num_inference_step = gr.Slider(
-                            minimum=1,
-                            maximum=100,
-                            step=1,
-                            value=50,
-                            label="Num Inference Step",
-                        )
+                                stable_diffusion_inpaint_seed_generator = (
+                                    gr.Number(
+                                        minimum=0,
+                                        maximum=1000000,
+                                        step=1,
+                                        value=0,
+                                        label="Seed Generator (0 for random)",
+                                    )
+                                )
 
                     stable_diffusion_inpaint_predict = gr.Button(
                         value="Generator"
@@ -117,6 +142,7 @@ class StableDiffusionInpaintGenerator:
                     stable_diffusion_inpiant_num_images_per_prompt,
                     stable_diffusion_inpaint_guidance_scale,
                     stable_diffusion_inpaint_num_inference_step,
+                    stable_diffusion_inpaint_seed_generator,
                 ],
                 outputs=[output_image],
             )
